bioneuralnet.downstream\_task.dpmon
===================================

.. automodule:: bioneuralnet.downstream_task.dpmon

   
   .. rubric:: Functions

   .. autosummary::
   
      build_omics_networks_tg
      get_logger
      run_hyperparameter_tuning
      run_standard_training
      setup_device
      slice_omics_datasets
      train_model
   
   .. rubric:: Classes

   .. autosummary::
   
      ASHAScheduler
      Autoencoder
      CLIReporter
      Checkpoint
      DPMON
      DimensionAveraging
      DownstreamTaskNN
      GAT
      GCN
      GIN
      NeuralNetwork
      Path
      SAGE
   